<?php

namespace Bixo\Offplan\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Offplan\Actions\FloorplanAction;
use Bixo\Offplan\Http\Requests\FloorplanActionRequest;
use Bixo\Offplan\Http\Resources\FloorplanResource;
use Bixo\Offplan\Models\Floorplan;

/**
 * Admin web controller class.
 */
class FloorplanActionController extends BaseController
{

    /**
     * Action controller function for floorplan.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(FloorplanActionRequest $request, Floorplan $floorplan, $action)
    {
        try {
            $request = $request->all();
            $floorplan = FloorplanAction::run($action, $floorplan, $request);

            $data = new FloorplanResource($floorplan);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('offplan::floorplan.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('offplan/floorplan/' . $floorplan->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('offplan/floorplan/' . $floorplan->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
