<?php

namespace Bixo\Offplan\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Offplan\Http\Resources\OffplanResource;
use Bixo\Offplan\Http\Resources\OffplansCollection;
use Bixo\Offplan\Scopes\FloorplanPublicScope;
use Bixo\Offplan\Models\Floorplan;

class FloorplanPublicController extends BaseController
{

    /**
     * Show floorplan's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Floorplan::pushScope(new RequestScope())
            ->pushScope(new FloorplanPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $floorplans = new FloorplansCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('offplan::floorplan.names'))
            ->view('offplan::public.floorplan.index')
            ->data(compact('floorplans', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show floorplan.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Floorplan::findBySlug($slug);
        $data = new FloorplanResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('offplan::floorplan.name'))
            ->view('offplan::public.floorplan.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
