<?php

namespace Bixo\Offplan\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Offplan\Actions\UnitAction;
use Bixo\Offplan\Http\Requests\UnitActionRequest;
use Bixo\Offplan\Http\Resources\UnitResource;
use Bixo\Offplan\Models\Unit;

/**
 * Admin web controller class.
 */
class UnitActionController extends BaseController
{

    /**
     * Action controller function for unit.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(UnitActionRequest $request, Unit $unit, $action)
    {
        try {
            $request = $request->all();
            $unit = UnitAction::run($action, $unit, $request);

            $data = new UnitResource($unit);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('offplan::unit.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('offplan/unit/' . $unit->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('offplan/unit/' . $unit->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
