<?php

namespace Bixo\Offplan\Providers;

use Illuminate\Support\ServiceProvider;
use Bixo\Offplan\Offplans;

class OffplanServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'offplan');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'offplan');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerCommands();

        $this->app->register(\Bixo\Offplan\Providers\AuthServiceProvider::class);
        $this->app->register(\Bixo\Offplan\Providers\RouteServiceProvider::class);
        $this->app->register(\Bixo\Offplan\Providers\ActionServiceProvider::class);
        $this->app->register(\Bixo\Offplan\Providers\EventServiceProvider::class);
        $this->app->register(\Bixo\Offplan\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('bixo.offplan', function($app)
        {
            return $this->app->make(Offplan::class);
        });
    }

    /**
     * Merges user's and offplan's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.offplan'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/booking.php', 'bixo.offplan.booking'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/floorplan.php', 'bixo.offplan.floorplan'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/payment.php', 'bixo.offplan.payment'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/project.php', 'bixo.offplan.project'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/unit.php', 'bixo.offplan.unit'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Bixo\Offplan\Commands\Offplan::class,
            ]);
        }
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.offplan'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('bixo/offplan')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/offplan')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/offplan')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
