<?php

namespace Bixo\Offplan\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Bixo\Offplan\Models\Booking;
use Bixo\Offplan\Models\Floorplan;
use Bixo\Offplan\Models\Payment;
use Bixo\Offplan\Models\Project;
use Bixo\Offplan\Models\Unit;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Bixo\Offplan\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/offplan/booking/*')) {
            Route::bind('booking', function ($booking) {
                return Booking::findorNew($booking);
            });
        }
        if (Request::is('*/offplan/floorplan/*')) {
            Route::bind('floorplan', function ($floorplan) {
                return Floorplan::findorNew($floorplan);
            });
        }
        if (Request::is('*/offplan/payment/*')) {
            Route::bind('payment', function ($payment) {
                return Payment::findorNew($payment);
            });
        }
        if (Request::is('*/offplan/project/*')) {
            Route::bind('project', function ($project) {
                return Project::findorNew($project);
            });
        }
        if (Request::is('*/offplan/unit/*')) {
            Route::bind('unit', function ($unit) {
                return Unit::findorNew($unit);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
